%define anolis_release 1

%global pubconfpath %{_sysconfdir}/gssproxy
%global gpstatedir %{_localstatedir}/lib/gssproxy
%global gpsockpath %{_rundir}/gssproxy.default.sock

Name:		gssproxy
Version:	0.9.2
Release:	%{anolis_release}%{?dist}
Summary:	Daemon for managing gss-api requests
License:	MIT
URL:		https://github.com/gssapi/gssproxy
Source0:	https://github.com/gssapi/gssproxy/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:	rwtab
Source2:    gssproxy.sock.compat.conf

Requires: krb5-libs >= 1.12.0 keyutils-libs libverto-module-base libini_config >= 1.2.0

### Patches ###
Patch0001: 0001-Fix-various-issues-detected-by-static-analysis.patch
Patch0002: 0002-Make-systemd-use-0700-mode-on-cache-folders.patch
Patch0003: 0003-gssproxy-Change-daemon-to-Type-notify-with-systemd.patch

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Conflicts: selinux-policy < 3.13.1-283.5

BuildRequires: autoconf automake make m4 systemd-units
BuildRequires: docbook-style-xsl doxygen
BuildRequires: findutils gettext-devel pkgconfig
BuildRequires: keyutils-libs-devel krb5-devel >= 1.12.0
BuildRequires: libini_config-devel >= 1.2.0 libselinux-devel
BuildRequires: libtool libverto-devel libxml2 libxslt popt-devel

%description
gssproxy allows the complexity of GSS security negotiation
to be centrallized.  It is particularly useful to keep this out
of kernel space, so that CIPFS, NFS, AFS etc can use GSS-API without
complexity in the kernel.

Using it also improves isolation and privilege separation, so that
HTTP servers, for example, can use GSS-API without needing to access
keys directly.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
autoreconf -f -i
%configure \
    --with-pubconf-path=%{pubconfpath} \
    --with-socket-name=%{gpsockpath} \
    --with-initscript=systemd \
    --disable-static \
    --disable-rpath \
    --with-gpp-default-behavior=REMOTE_FIRST

make %{?_smp_mflags} all
make test_proxymech

%install
%make_install
mkdir -p %{buildroot}%{_sysconfdir}/gssproxy
for file in gssproxy.conf 99-network-fs-clients.conf; do
    install -m 0644 examples/$file %{buildroot}%{_sysconfdir}/gssproxy/$file
done
mkdir -p %{buildroot}/%{_sysconfdir}/rwtab.d
mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/rwtab.d/gssproxy
install -m 0644 %{SOURCE2} %{buildroot}/%{_tmpfilesdir}/gssproxy.conf
mkdir -p %{buildroot}%{gpstatedir}/rcache
ln -s %{_rundir}/gssproxy.default.sock %{buildroot}%{gpstatedir}/default.sock

%generate_compatibility_deps

%pre
if [ -S %{gpstatedir}/default.sock ]; then
    rm -f %{gpstatedir}/default.sock
fi

%post
%systemd_post gssproxy.service

%preun
%systemd_preun gssproxy.service

%postun
%systemd_postun_with_restart gssproxy.service

%files
%dir %{abidir}
%license COPYING
%{_unitdir}/gssproxy.service
%{_sbindir}/gssproxy
%{abidir}/gssproxy-option.list
%{_userunitdir}/gssuserproxy.service
%{_userunitdir}/gssuserproxy.socket
%attr(755,root,root) %dir %{pubconfpath}
%attr(755,root,root) %dir %{gpstatedir}
%attr(700,root,root) %dir %{gpstatedir}/clients
%attr(700,root,root) %dir %{gpstatedir}/rcache
%{gpstatedir}/default.sock
%config(noreplace) /%{_sysconfdir}/gssproxy/gssproxy.conf
%config(noreplace) /%{_sysconfdir}/gssproxy/99-network-fs-clients.conf
%config(noreplace) /%{_sysconfdir}/gss/mech.d/proxymech.conf
%{_tmpfilesdir}/%{name}.conf
%dir %{_libdir}/gssproxy
%{_libdir}/gssproxy/proxymech.so
%{abidir}/proxymech.dump
%config(noreplace) %{_sysconfdir}/rwtab.d/gssproxy
%{_mandir}/man5/gssproxy.conf.5*
%{_mandir}/man8/gssproxy-mech.8*
%{_mandir}/man8/gssproxy.8*

%files doc
%doc README.md BUILD.txt version.m4

%changelog
* Tue Feb 18 2025 Xiaoping Liu <lxp01404969@linux.alibaba.com> - 0.9.2-1
- update to 0.9.2 from 0.9.1
- Make systemd use 0700 mode on cache folders
- Change daemon to Type=notify with systemd
- Fix various issues detected by static analysis

* Mon Apr 10 2023 yuanhui <yuanhui@linux.alibaba.com> - 0.9.1-2
- Optimize the spec file

* Tue Feb 14 2023 yuanhui <yuanhui@linux.alibaba.com> - 0.9.1-1
- update to 0.9.1

* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.8.4-2
- optimise spec file

* Fri Mar 11 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.8.4-1
- init from upstream 0.8.3
